#!/usr/bin/env python

from aflow_chull import CHull
import json
from pprint import pprint

#elements = ['H', 'He', 'Li', 'Be', 'B', 'C', 'N', 'O', 'F', 'Ne', 'Na', 'Mg', 'Al', 'Si', 'P', 'S', 'Cl', 'Ar', 'K', 'Ca', 'Sc', 'Ti', 'V', 'Cr', 'Mn', 'Fe', 'Co', 'Ni', 'Cu', 'Zn', 'Ga', 'Ge', 'As', 'Se', 'Br', 'Kr', 'Rb', 'Sr', 'Y', 'Zr', 'Nb', 'Mo', 'Tc', 'Ru', 'Rh', 'Pd', 'Ag', 'Cd', 'In', 'Sn', 'Sb', 'Te', 'I', 'Xe', 'Cs', 'Ba', 'La', 'Ce', 'Pr', 'Nd', 'Pm', 'Sm', 'Eu', 'Gd', 'Tb', 'Dy', 'Ho', 'Er', 'Tm', 'Yb', 'Lu', 'Hf', 'Ta', 'W', 'Re', 'Os', 'Ir', 'Pt', 'Au', 'Hg', 'Tl', 'Pb', 'Bi', 'Ac', 'Th', 'Pa']
elements = ['Mn', 'Pd', 'Pt'] #extend as needed
elements.sort()

most_stable_binaries = [] #final list
saved_points_rc = []      #easy way to avoid adding duplicate compositions

chull = CHull(aflow_executable = '~/bin/aflow') #initialize hull object
for i in range(len(elements)):              #generate binary alloy combinations
    for j in range(i + 1, len(elements)):   #generate binary alloy combinations
        alloy = elements[i]+elements[j]     #generate binary alloy combinations
        output = chull.get_hull(alloy)      #get hull data
        points_data = output['points_data'] #grab points data
        for point in points_data:
            #filter for binary ground-state structures not in the ICSD
            if point['ground_state'] and not point['icsd_ground_state'] and point['nspecies'] == 2:
                #easy way to avoid adding duplicate compositions
                if point['reduced_compound'] not in saved_points_rc:
                    saved_points_rc.append(point['reduced_compound'])
                    #save only what is necessary
                    abridged_entry = {}
                    abridged_entry['compound'] = point['compound']
                    abridged_entry['prototype'] = point['prototype']
                    abridged_entry['auid'] = point['auid']
                    abridged_entry['aurl'] = point['aurl']
                    abridged_entry['relative_stability_criterion'] = point['relative_stability_criterion']
                    most_stable_binaries.append(abridged_entry)

most_stable_binaries = sorted(most_stable_binaries, key=lambda point: -point['relative_stability_criterion'])    #sort in descending order

#save data to JSON file
with open('most_stable_binaries.json', 'w') as fout:
    json.dump(most_stable_binaries, fout)

#also print output to screen
pprint(most_stable_binaries)
